@@ -1,4 +1,3 @@
-/* $Id: adt_sp.c 616 2005-08-19 20:11:01Z bruce $ */
 #include <stdlib.h>
 #include <string.h>
 
@@ -16,7 +15,7 @@ int adt_copysp(const char** a, const char* const* b)
 
 adt_hash_t adt_hashsp(const char* const* p)
 {
-  return adt_hashs(*p);
+  return adt_hashs((const unsigned char*)*p);
 }
 
 void adt_freesp(const char** a)
