@@ -1,4 +1,3 @@
-/* $Id: find.c 616 2005-08-19 20:11:01Z bruce $ */
 /* Adapted from public domain sources written by D. J. Bernstein */
 
 #include <errno.h>
@@ -7,7 +6,7 @@
 #include "cdb.h"
 #include "uint32.h"
 
-int cdb_read(struct cdb *c,char *buf,unsigned int len,uint32 pos)
+int cdb_read(struct cdb *c,unsigned char *buf,unsigned int len,uint32 pos)
 {
   if (c->map) {
     if ((pos > c->size) || (c->size - pos < len)) goto FORMAT;
@@ -39,7 +38,7 @@ int cdb_read(struct cdb *c,char *buf,unsigned int len,uint32 pos)
 
 static int match(struct cdb *c,const char *key,unsigned int len,uint32 pos)
 {
-  char buf[32];
+  unsigned char buf[32];
   unsigned int n;
 
   while (len > 0) {
@@ -56,7 +55,7 @@ static int match(struct cdb *c,const char *key,unsigned int len,uint32 pos)
 
 int cdb_findnext(struct cdb *c,const char *key,unsigned int len)
 {
-  char buf[8];
+  unsigned char buf[8];
   uint32 pos;
   uint32 u;
 
