@@ -1,4 +1,3 @@
-/* $Id: getnext.c 639 2005-11-21 04:43:14Z bruce $ */
 /* cdb/strgetnext.c -- Retrieve the next record from a CDB as a str
  * Copyright (C) 2001,2005  Bruce Guenter <bruce@untroubled.org>
  *
@@ -25,7 +24,8 @@ int cdb_getnext(struct cdb* cdb, const str* key, str* data)
   if (cdb == 0 || key == 0 || data == 0) return -1;
   if (!cdb_findnext(cdb, key->s, key->len)) return 0;
   if (!str_ready(data, cdb->dlen)) return -1;
-  if (cdb_read(cdb, data->s, cdb->dlen, cdb->dpos) == -1) return -1;
+  if (cdb_read(cdb, (unsigned char*)data->s, cdb->dlen, cdb->dpos) == -1)
+    return -1;
   data->len = cdb->dlen;
   data->s[data->len] = 0;
   return 1;
