@@ -1,4 +1,3 @@
-/* $Id: make.h 616 2005-08-19 20:11:01Z bruce $ */
 /* Public domain. */
 
 #ifndef CDB_MAKE_H
@@ -18,7 +17,7 @@ struct cdb_hplist {
 } ;
 
 struct cdb_make {
-  char final[2048];
+  unsigned char final[2048];
   uint32 count[256];
   uint32 start[256];
   struct cdb_hplist *head;
