@@ -1,8 +1,7 @@
-/* $Id: str.h 616 2005-08-19 20:11:01Z bruce $ */
 #ifndef CDB__STR__H__
 #define CDB__STR__H__
 
-#include "cdb.h"
+#include <cdb/cdb.h>
 struct str;
 
 extern int cdb_get(struct cdb*, const struct str* key, struct str* data);
