@@ -1,8 +1,7 @@
-/* $Id: load.h 616 2005-08-19 20:11:01Z bruce $ */
 #ifndef DICT__LOAD__H__
 #define DICT__LOAD__H__
 
-#include "dict.h"
+#include <dict/dict.h>
 
 extern int dict_load_list(dict*, const char* filename,  int mustexist,
 			  int (*xform)(str*));
