@@ -1,4 +1,3 @@
-/* $Id: multi.c 638 2005-11-21 04:39:57Z bruce $ */
 /* fmt/multi.c - Format multiple items.
  * Copyright (C) 2005  Bruce Guenter <bruce@untroubled.org>
  *
@@ -16,11 +15,13 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
+#include <errno.h>
 #include <stdarg.h>
 #include <string.h>
 #include "misc.h"
 #include "multi.h"
 #include "number.h"
+#include "str/str.h"
 
 /** Format multiple items.
 
@@ -82,8 +83,12 @@ hexadecimal, or uppercase unsigned hexadecimal string respectively.
 
 <dt>\c s <dd>The \c const \c char* argument is converted.
 
+<dt>\c S <dd>The \c const \c str* argument is converted.
+
 <dt>\c p <dd>The \c void* argument is converted to a hexadecimal string.
 
+<dt>\c m <dd>The result of \c strerror(errno) is formatted.
+
 <dt>\c \\ <dd>The next character literal from the format string is
 converted as with \c c conversion.
 
@@ -153,6 +158,7 @@ unsigned fmt_multiv(char* buffer, const char* format, va_list ap)
     long long value = 0;
     const char* altstr;
     char conv;
+    const str* strp;
 
     for (; *format != 0; ++format) {
       switch (*format) {
@@ -214,10 +220,17 @@ unsigned fmt_multiv(char* buffer, const char* format, va_list ap)
     case 's':
       ilength = fmt_chars(buffer, va_arg(ap, const char*), width, pad);
       break;
+    case 'S':
+      strp = va_arg(ap, const str*);
+      ilength = fmt_mem(buffer, strp->s, strp->len, width, pad);
+      break;
     case 'p':
       ilength = fmt_unumwa(buffer, (unsigned long)va_arg(ap, void*),
 			   width, pad, 16, fmt_lcase_digits, "0x");
       break;
+    case 'm':
+      ilength = fmt_chars(buffer, strerror(errno), width, pad);
+      break;
     case '\\':
       ilength = fmt_char(buffer, *++format, width, pad);
       break;
