@@ -1,4 +1,3 @@
-/* $Id: ullnum.c 639 2005-11-21 04:43:14Z bruce $ */
 /* fmt/ullnum.c - Format an unsigned long long number.
  * Copyright (C) 2004,2005  Bruce Guenter <bruce@untroubled.org>
  *
@@ -44,9 +43,9 @@ unsigned fmt_ullnumw(char* buffer, unsigned long long num,
   char* s = buffer;
   if (buffer == 0) {
     unsigned len;
-    for (len = 0; num > 0; ++len)
+    for (len = 1; num >= base; ++len)
       num /= base;
-    return len + ((width > len) ? width - len : 0);
+    return (width > len) ? width : len;
   }
   if (num < base) {
     if (width) {
@@ -76,6 +75,7 @@ static void test(unsigned (*fn)(char*, unsigned long long, unsigned, char),
 
 MAIN
 {
+  test(fmt_ulldecw,  0, 0,   0);
   test(fmt_ulldecw, 10, 0,   0);
   test(fmt_ulldecw, 10, 1, ' ');
   test(fmt_ulldecw, 10, 5, ' ');
@@ -89,6 +89,7 @@ MAIN
 }
 #endif
 #ifdef SELFTEST_EXP
+1:0
 2:10
 2:10
 5:   10
