@@ -1,4 +1,3 @@
-/* $Id: ibuf_openreadclose.c 616 2005-08-19 20:11:01Z bruce $ */
 #include <iobuf/iobuf.h>
 #include <str/str.h>
 
@@ -8,7 +7,7 @@ int ibuf_openreadclose(const char* filename, struct str* out)
   ibuf in;
   int r;
   if (!ibuf_open(&in, filename, 0))
-    return -1;
+    return 0;
   r = ibuf_readall(&in, out);
   ibuf_close(&in);
   return r;
