@@ -1,4 +1,3 @@
-/* $Id: wrap_alloc.c 616 2005-08-19 20:11:01Z bruce $ */
 #include "msg.h"
 #include "wrap.h"
 
@@ -10,9 +9,7 @@ void wrap_alloc(const void* p)
 
 #ifdef SELFTEST_MAIN
 #include "selftest.c"
-const char program[] = "testprog";
-const int msg_show_pid = 0;
-void selftest(void)
+MAIN
 {
   wrap_exit = 0;
   wrap_alloc(selftest);
@@ -22,5 +19,5 @@ void selftest(void)
 #endif
 #ifdef SELFTEST_EXP
 worked
-testprog: Fatal: Out of memory
+selftest: Fatal: Out of memory
 #endif
