@@ -1,4 +1,3 @@
-/* $Id: wrap_chdir.c 616 2005-08-19 20:11:01Z bruce $ */
 #include <unistd.h>
 
 #include "msg.h"
@@ -12,9 +11,7 @@ void wrap_chdir(const char* dir)
 
 #ifdef SELFTEST_MAIN
 #include "selftest.c"
-const char program[] = "testprog";
-const int msg_show_pid = 0;
-void selftest(void)
+MAIN
 {
   wrap_exit = 0;
   wrap_chdir(".");
@@ -24,5 +21,5 @@ void selftest(void)
 #endif
 #ifdef SELFTEST_EXP
 worked
-testprog: Fatal: Could not chdir to '/this/dir/should/not/exist': No such file or directory
+selftest: Fatal: Could not chdir to '/this/dir/should/not/exist': No such file or directory
 #endif
