@@ -1,4 +1,3 @@
-/* $Id: connect4.c 639 2005-11-21 04:43:14Z bruce $ */
 /* net/connect4.c - Make an IPv4 connection
  * Copyright (C) 2001,2005  Bruce Guenter <bruce@untroubled.org>
  *
@@ -35,3 +34,28 @@ int socket_connect4(int sock, const ipv4addr* ip, ipv4port port)
   sa.sin_port = htons(port);
   return connect(sock, (struct sockaddr*)&sa, sizeof sa) == 0;
 }
+
+#ifdef SELFTEST_MAIN
+#include "selftest.c"
+MAIN
+{
+  int sock1;
+  int sock2;
+  ipv4port port = 12345;
+  debugsys((sock1 = socket_tcp4()) >= 0);
+  debugsys(socket_reuse(sock1));
+  for (port = 12345; port < 32768; ++port)
+    if (socket_bind4(sock1, &IPV4ADDR_ANY, port) == 0)
+      break;
+  debugsys(socket_listen(sock1, 1));
+  debugsys((sock2 = socket_tcp4()) >= 0 && sock2 != sock1);
+  debugsys(socket_connect4(sock2, &IPV4ADDR_LOOPBACK, port));
+}
+#endif
+#ifdef SELFTEST_EXP
+result=1
+result=1
+result=1
+result=1
+result=0
+#endif
