@@ -1,4 +1,3 @@
-/* $Id: connected.c 639 2005-11-21 04:43:14Z bruce $ */
 /* net/connected.c - Test if a socket is connected
  * Copyright (C) 2001,2005  Bruce Guenter <bruce@untroubled.org>
  *
@@ -25,7 +24,7 @@
 int socket_connected(int sock)
 {
   struct sockaddr sa;
-  int dummy;
+  socklen_t dummy;
   char ch;
   
   dummy = sizeof sa;
