@@ -1,4 +1,3 @@
-/* $Id: ipv4.h 616 2005-08-19 20:11:01Z bruce $ */
 #ifndef NET__IPV4__H__
 #define NET__IPV4__H__
 
@@ -20,7 +19,7 @@ extern const ipv4addr IPV4ADDR_ANY;
 extern const ipv4addr IPV4ADDR_BROADCAST;
 extern const ipv4addr IPV4ADDR_LOOPBACK;
 
-extern int ipv4_parse(const char* s, ipv4addr* addr, const char** end) __DEPRECATED__;
+extern int ipv4_parse(const char* s, ipv4addr* addr, const char** end) __attribute__((__deprecated__));
 extern const char* ipv4_scan(const char* s, ipv4addr* addr);
 extern const char* ipv4_format(const ipv4addr* addr);
 extern unsigned fmt_ipv4addr(char* buffer, const ipv4addr* addr);
