@@ -1,4 +1,3 @@
-/* $Id: ipv6_scan.c 616 2005-08-19 20:11:01Z bruce $ */
 #include "ipv6.h"
 #include "ipv4.h"
 
@@ -135,7 +134,7 @@ static void test(const char* start)
   obuf_flush(&outbuf);
 }
 
-void selftest(void)
+MAIN
 {
   test("::");
   test("::1");
