@@ -1,10 +1,13 @@
-/* $Id: selftest.c 616 2005-08-19 20:11:01Z bruce $ */
+#include <errno.h>
 #include <string.h>
 
 #include "iobuf/iobuf.h"
 #include "msg/msg.h"
 #include "str/str.h"
 
+const char program[] = "selftest";
+const int msg_show_pid = 0;
+
 void NL(void) { obuf_putc(&outbuf, LF); }
 
 void debugstr(const str* s)
@@ -39,6 +42,18 @@ int debugfn(int result)
   return result;
 }
 
+int debugsys(int result)
+{
+  obuf_puts(&outbuf, "result=");
+  obuf_puti(&outbuf, result);
+  NL();
+  if (result == -1) {
+    obuf_puts(&outbuf, strerror(errno));
+    NL();
+  }
+  return result;
+}
+
 #define MAIN void selftest(void)
 MAIN;
 
