@@ -1,4 +1,3 @@
-/* $Id: alloc.c 638 2005-11-21 04:39:57Z bruce $ */
 /* str/alloc.c - Allocate storage for a string
  * Copyright (C) 2002-2005  Bruce Guenter <bruce@untroubled.org>
  *
@@ -59,7 +58,7 @@ void test(str* s, unsigned size)
 {
   debugstrfn(str_alloc(s, size, 0), s);
 }
-void selftest(void)
+MAIN
 {
   static str s;
   test(&s, 0);
