@@ -1,4 +1,3 @@
-/* $Id: catf.c 638 2005-11-21 04:39:57Z bruce $ */
 /* str/catf.c - Append formatted data to a string
  * Copyright (C) 2005  Bruce Guenter <bruce@untroubled.org>
  *
@@ -50,7 +49,7 @@ int str_catf(str* s, const char* format, ...)
 
 #ifdef SELFTEST_MAIN
 #include "selftest.c"
-void selftest(void)
+MAIN
 {
   static str s;
   str_copys(&s, "foo");
