@@ -1,4 +1,3 @@
-/* $Id: copy.c 639 2005-11-21 04:43:14Z bruce $ */
 /* str/copy.c - Copy one string into another
  * Copyright (C) 2001,2005  Bruce Guenter <bruce@untroubled.org>
  *
@@ -43,7 +42,7 @@ int str_copyb(str* s, const char* in, unsigned len)
 
 #ifdef SELFTEST_MAIN
 #include "selftest.c"
-void selftest(void)
+MAIN
 {
   static str s;
   debugstrfn(str_copys(&s, "foo"), &s);
