@@ -1,4 +1,3 @@
-/* $Id: copyf.c 638 2005-11-21 04:39:57Z bruce $ */
 /* str/copyf.c - Copy formatted data into a string
  * Copyright (C) 2005  Bruce Guenter <bruce@untroubled.org>
  *
@@ -50,7 +49,7 @@ int str_copyf(str* s, const char* format, ...)
 
 #ifdef SELFTEST_MAIN
 #include "selftest.c"
-void selftest(void)
+MAIN
 {
   static str s;
   debugstrfn(str_copyf(&s, "d{bar}x", 10, 20), &s);
