@@ -1,4 +1,3 @@
-/* $Id: env_from_array.c 616 2005-08-19 20:11:01Z bruce $ */
 #include <string.h>
 #include "str.h"
 #include "env.h"
@@ -19,7 +18,7 @@ int envstr_from_array(struct str* env, char** array, int overwrite)
 
 #ifdef SELFTEST_MAIN
 #include "selftest.c"
-void selftest(void)
+MAIN
 {
   static str env;
   char* array[3] = {"A=1","B=2",0};
