@@ -1,4 +1,3 @@
-/* $Id: env_from_string.c 616 2005-08-19 20:11:01Z bruce $ */
 #include <string.h>
 #include "str.h"
 #include "env.h"
@@ -19,7 +18,7 @@ int envstr_from_string(struct str* env, const char* s, int overwrite)
 
 #ifdef SELFTEST_MAIN
 #include "selftest.c"
-void selftest(void)
+MAIN
 {
   static str env;
   debugstrfn(envstr_from_string(&env, "A=3\0C=4\0", 1), &env);
