@@ -1,4 +1,3 @@
-/* $Id: env_get.c 616 2005-08-19 20:11:01Z bruce $ */
 #include <string.h>
 #include "str.h"
 #include "iter.h"
@@ -15,7 +14,7 @@ const char* envstr_get(const struct str* env, const char* var)
 
 #ifdef SELFTEST_MAIN
 #include "selftest.c"
-void selftest(void)
+MAIN
 {
   static const str env = {"A=1\0B=2\0C=3\0", 12, 0};
   const char* c;
