@@ -1,4 +1,3 @@
-/* $Id: env_put.c 616 2005-08-19 20:11:01Z bruce $ */
 #include <string.h>
 #include "str.h"
 #include "env.h"
@@ -24,7 +23,7 @@ int envstr_put(struct str* env, const char* asgn, int overwrite)
 
 #ifdef SELFTEST_MAIN
 #include "selftest.c"
-void selftest(void)
+MAIN
 {
   static str env;
   debugstrfn(envstr_put(&env, "A=4", 0), &env);
