@@ -1,4 +1,3 @@
-/* $Id: env_set.c 616 2005-08-19 20:11:01Z bruce $ */
 #include <string.h>
 #include "str.h"
 #include "env.h"
@@ -20,7 +19,7 @@ int envstr_set(struct str* env, const char* var, const char* val, int overwrite)
 
 #ifdef SELFTEST_MAIN
 #include "selftest.c"
-void selftest(void)
+MAIN
 {
   static str env;
   debugstrfn(envstr_set(&env, "A", "4", 0), &env);
