@@ -1,4 +1,3 @@
-/* $Id: findnextof.c 639 2005-11-21 04:43:14Z bruce $ */
 /* str/findnextof.c - Find the next character of a set in a string
  * Copyright (C) 2001,2005  Bruce Guenter <bruce@untroubled.org>
  *
@@ -34,7 +33,7 @@ int str_findnextof(const str* s, const char* list, unsigned pos)
 
 #ifdef SELFTEST_MAIN
 #include "selftest.c"
-void selftest(void)
+MAIN
 {
   str s = { "01234567890123456", 16, 0 };
   obuf_puti(&outbuf, str_findnextof(&s, "654", 0)); NL();
