@@ -1,4 +1,3 @@
-/* $Id: findprev.c 638 2005-11-21 04:39:57Z bruce $ */
 /* str/findprev.c - Find the previous instance of a character
  * Copyright (C) 2001,2005  Bruce Guenter <bruce@untroubled.org>
  *
@@ -34,7 +33,7 @@ int str_findprev(const str* s, char ch, unsigned pos)
 
 #ifdef SELFTEST_MAIN
 #include "selftest.c"
-void selftest(void)
+MAIN
 {
   str s = { "01234567890123456", 16, 0 };
   str e = { 0, 0, 0 };
