@@ -1,4 +1,3 @@
-/* $Id: findprevof.c 638 2005-11-21 04:39:57Z bruce $ */
 /* str/findprevof.c - Find the previous instance of a character set
  * Copyright (C) 2001,2005  Bruce Guenter <bruce@untroubled.org>
  *
@@ -38,7 +37,7 @@ int str_findprevof(const str* s, const char* list, unsigned pos)
 
 #ifdef SELFTEST_MAIN
 #include "selftest.c"
-void selftest(void)
+MAIN
 {
   str s = { "01234567890123456", 16, 0 };
   str e = { 0, 0, 0 };
