@@ -1,4 +1,3 @@
-/* $Id: free.c 639 2005-11-21 04:43:14Z bruce $ */
 /* str/free.c - Free the storage allocated by a string
  * Copyright (C) 2001,2005  Bruce Guenter <bruce@untroubled.org>
  *
@@ -32,7 +31,7 @@ void str_free(str* s)
 
 #ifdef SELFTEST_MAIN
 #include "selftest.c"
-void selftest(void)
+MAIN
 {
   static str s;
   str_alloc(&s, 1, 0);
