@@ -1,4 +1,3 @@
-/* $Id: init.c 639 2005-11-21 04:43:14Z bruce $ */
 /* str/init.c - Initialize a string to a minimum size
  * Copyright (C) 2001,2005  Bruce Guenter <bruce@untroubled.org>
  *
@@ -33,7 +32,7 @@ int str_init(str* s)
 
 #ifdef SELFTEST_MAIN
 #include "selftest.c"
-void selftest(void)
+MAIN
 {
   static str s;
   debugstrfn(str_init(&s), &s);
