@@ -1,4 +1,3 @@
-/* $Id: splice.c 639 2005-11-21 04:43:14Z bruce $ */
 /* str/splice.c - Insert into the middle of a string.
  * Copyright (C) 2003,2005  Bruce Guenter <bruce@untroubled.org>
  *
@@ -50,7 +49,7 @@ int str_spliceb(str* s, unsigned start, unsigned len,
 
 #ifdef SELFTEST_MAIN
 #include "selftest.c"
-void selftest(void)
+MAIN
 {
   static str s;
   str_copyb(&s, "abcde", 5);
