@@ -1,4 +1,3 @@
-/* $Id: getpeereid.c 616 2005-08-19 20:11:01Z bruce $ */
 #include "sysdeps.h"
 
 #if ! HASGETPEEREID
@@ -12,7 +11,7 @@ int getpeereid(int s, uid_t* u, gid_t* g)
 {
 #if HASPEERCRED
   struct ucred peer;
-  int optlen = sizeof peer;
+  socklen_t optlen = sizeof peer;
   if (getsockopt(s, SOL_SOCKET, SO_PEERCRED, &peer, &optlen) == -1)
     return -1;
   if (u != 0)
